function dydt = eqPendolo(t,y)
% EQPENDOLO Equazione diff. pendolo
% SINTASSI
% dydt = eqPendolo(t,y)
% INPUT
% t : Valore corrente della variabile indipendente
% y : Valore corrente della variabile dipendente
% OUTPUT
% dydt : Valore di f(t,y) in t e y
% costante di gravita'
g = 9.81;
% lunghezza del pendolo
l = 10;
% equazione differenziale

% dydt(1)=y(2);
% dydt(2)=-g/l*sin(y(1));
dydt= [y(2);-g/l*sin(y(1))]';

